import "./endQuizModal.css";
import { ModalButton } from "../modalButton/modalButton.tsx";
import { useNavigate } from "react-router-dom";
import { Quiz } from "../../../models/Quiz.ts";
import { QuizInformations } from "../../../models/QuizInformations.ts";
import { useQuizService } from "../../../services/QuizService.ts";

interface Props {
    isOpen: boolean;
    quizInformations: QuizInformations;
    score: number;
    setIsOpen: (isOpen: boolean) => void;
}

export const EndQuizModal = ({ isOpen, quizInformations, score, setIsOpen }: Props) => {
    if (!isOpen) return null;
    const navigate = useNavigate();
    const { createRun } = useQuizService();

    const handleRestart = async () => {
        const quizId = quizInformations.id;
        const runId = await createRun(quizId.toString());
        setIsOpen(false);
        navigate("/quiz/" + runId, { state: { quizId: quizId } });
        navigate(0);
    };

    const handleBackToMenu = () => {
        navigate("/home");
    };
    return (
        <div className="modal-end-quiz-modal-overlay">
            <div className="end-quiz-modal-content" onClick={(e) => e.stopPropagation()}>
                <div>
                    <p className="end-quiz-modal-button-title">CONGRATS !</p>
                </div>
                <div className="end-quiz-modal-button-text-container">
                    <p className="end-quiz-modal-button-text">YOU FINISH THE TEST WITH A</p>
                    <p className="end-quiz-modal-button-text">
                        SCORE OF {score}/{quizInformations.questionCount} !
                    </p>
                </div>
                <div className="end-quiz-modal-image-container">
                    <img
                        src="/CONGRATS_ILLUSTRATION.png"
                        alt="Congratulations illustration"
                        className="end-quiz-modal-image"
                    />
                </div>
                <div className="end-quiz-modal-button-container">
                    <ModalButton text="RESTART" onClick={handleRestart} isLeftButton={true} isDisabled={false} />
                    <ModalButton
                        text="BACK TO MENU"
                        onClick={handleBackToMenu}
                        isLeftButton={false}
                        isDisabled={false}
                    />
                </div>
            </div>
        </div>
    );
};
