import { StrictMode } from "react";
import { createRoot } from "react-dom/client";
import "./index.css";
import { createBrowserRouter, RouterProvider, Navigate, useParams } from "react-router-dom";
import Root from "./routes/root.tsx";

import { Home } from "./routes/home/home.tsx";
import { Community } from "./routes/community/community.tsx";
import { Profile } from "./routes/profile/profile.tsx";
import { CreateQuiz } from "./routes/createQuiz/createQuiz.tsx";
import { PlayingQuiz } from "./routes/quiz/playingQuiz.tsx";
import { Multiplayer } from "./routes/multiplayer/multiplayer.tsx";
import { Lobby } from "./routes/multiplayer/Lobby/lobby.tsx";
import { EditQuiz } from "./routes/editQuiz/editQuiz.tsx";
import {PlayingQuizMulti} from "./routes/multiplayer/quiz/PlayingQuizMulti.tsx";
import {EventSourceProvider} from "./components/EventSourceContextType.tsx";

const router = createBrowserRouter([
    {
        path: "/",
        element: <Root />,
        children: [
            {
                index: true, // Définit cette route comme la route par défaut
                element: <Navigate to="home" replace />,
            },
            {
                path: "home",
                element: <Home />,
            },
            {
                path: "community",
                element: <Community />,
            },
            {
                path: "profile",
                element: <Profile />,
            },
            {
                path: "multiplayer",
                element: <Multiplayer />,
            },
            {
                path: "createquiz",
                element: <CreateQuiz />,
            },
            {
                path: "editquiz",
                element: <EditQuiz />,
            },
            {
                path: "quiz/:id",
                element: <PlayingQuiz />,
            },
            {
                path: "quizMulti/:id",
                element: <PlayingQuizMulti />,
            },
            {
                path: "lobby/:id",
                element: <Lobby />,
            },
        ],
    },
]);

createRoot(document.getElementById("root")!).render(
    <StrictMode>
        <EventSourceProvider>
            <RouterProvider router={router} />
        </EventSourceProvider>
    </StrictMode>
);
