import { useState } from "react";
import "./detailQuiz.css";
import "../../../index.css";
import { useNavigate } from "react-router-dom";
import { useQuizService } from "../../../services/QuizService.ts";
import { Quiz } from "../../../models/Quiz.ts";
import { useMultiplayerService } from "../../../services/MultiplayerService.ts";
import Swal from "sweetalert2";

interface Props {
    quiz: Quiz | null;
    isMulty?: boolean;
}

// right side for community. after choose A Quiz. Show the detail of this quiz and allow you to play it.
export function DetailQuiz({ quiz, isMulty }: Props) {
    const navigate = useNavigate();
    const { createRun } = useQuizService();
    const handlePlay = async () => {
        if (isMulty) {
            navigate("/lobby/" + quiz.id, { state: { isHost: true } });
            return;
        }
        const quizId = quiz.id;
        const runId = await createRun(quizId);
        navigate(`/quiz/${runId}`, { state: { quizId: quizId } });
    };
    return (
        <div className="container-left">
            {!quiz ? (
                <p>clic on a quiz to see its infos</p>
            ) : (
                <div className="container-detail-element">
                    <h2>{quiz.name ?? "Unnamed Quiz"}</h2>
                    <p className={!quiz.description ? "" : "italic"}>{quiz.description ?? "No description"}</p>
                    <div className="quiz-info">
                        <div className="quiz-title">
                            <p className="quiz-info-title">About this quiz</p>
                            <hr />
                        </div>
                        <div className="quiz-info-content">
                            <p className="quiz-info-content-value">{`${quiz.questionCount} Questions, ${quiz.difficulty.name}`}</p>
                        </div>
                        {/*<div className="quiz-info-content">
                            <p className="quiz-info-content-value">{`Played by <NbQuizzers> quizzers`}</p>{/* TOOO: NbQuizzers
                        </div>*/}
                        <div className="quiz-info-content">
                            <p className="quiz-info-content-value">{`By : ${quiz.author.username ?? "Unnamed Author"
                                }`}</p>
                        </div>
                    </div>
                    <button className="blueButton" onClick={handlePlay}>
                        {isMulty ? "CREATE A LOBBY" : "Play"}
                    </button>
                </div>
            )}
        </div>
    );
}
