import AutoAwesomeIcon from '@mui/icons-material/AutoAwesome';
import { useState } from 'react';
import { useOllamaService } from '../../../services/OllamaService';
import { AnswerCreation } from '../../../models/Answer';
import './generateAnswer.css';

interface Props {
    question: string;
    index: number;
    updateAnswer: (text: string) => void;
}

export default function GenerateAnswer({ question, index, updateAnswer }: Props) {
    const MODE = ['REALISTIC', 'HUMOUR'];
    const [showMode, setShowMode] = useState(false);
    const [selectedMode, setSelectedMode] = useState(MODE[0]);
    const [isloading, setIsLoading] = useState(false);
    const { generateTrueAnswer, generateFalseAnswer } = useOllamaService();

    const handleGenerateAnswer = async () => {
        
        if (index === 0) {
            setIsLoading(true);
            const generatedText = await generateTrueAnswer(question);
            updateAnswer(generatedText.answer);
            setIsLoading(false);
            return;
        }
        if (showMode) {
            setIsLoading(true);
            const generatedText = await generateFalseAnswer(question, selectedMode);
            updateAnswer(generatedText.answer);
            setIsLoading(false);
        }
        setShowMode(!showMode);
    };

    return (
        <div className='generate-answer-container'>
            {showMode &&
                <select 
                    value={selectedMode}
                    onChange={(e) => setSelectedMode(e.target.value)}
                    className='generate-answer-select'
                >
                    {MODE.map((mode, index) => (
                        <option key={index} value={mode}>{mode}</option>
                    ))}
                </select>
            }
            <div className="generate-answer-button" onClick={handleGenerateAnswer} aria-disabled={isloading}>
                <AutoAwesomeIcon className={isloading ? 'greyIcon' : 'yellowIcon'}/>
            </div>
        </div>
    );
}