import DeleteOutlineOutlinedIcon from "@mui/icons-material/DeleteOutlineOutlined";
import CheckOutlinedIcon from "@mui/icons-material/CheckOutlined";
import CloseOutlinedIcon from "@mui/icons-material/CloseOutlined";
import { useState } from "react";
import { Answer, AnswerCreation } from "../../models/Answer";

interface ITextQuizProps {
    answers: AnswerCreation[];
    indexQuestion: number;
    updateAnswer: (text: string, indexQuestion: number, index: number) => void;
    handleDeleteAnswer: (e: React.MouseEvent, indexQuestion: number, index: number) => void;
}

export default function SoundQuiz({ answers, indexQuestion, updateAnswer, handleDeleteAnswer }: ITextQuizProps) {
    const [previews, setPreviews] = useState<string[]>(answers.map((a) => a.text || ""));

    const convertToBase64 = (file: File): Promise<string> => {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.onload = () => resolve(reader.result as string);
            reader.onerror = (error) => reject(error);
            reader.readAsDataURL(file);
        });
    };

    const handleFileChange = async (e: React.ChangeEvent<HTMLInputElement>, indexQuestion: number, index: number) => {
        if (e.target.files && e.target.files[0]) {
            const file = e.target.files[0];
            if (file.size > 1048576) {
                alert("Le fichier est trop volumineux. La taille maximale autorisée est de 1 Mo.");
                return;
            }
            try {
                const base64 = await convertToBase64(file);
                setPreviews((prev) => {
                    const updated = [...prev];
                    updated[index] = base64;
                    return updated;
                });
                updateAnswer(base64, indexQuestion, index);
            } catch (error) {
                console.error("Error converting file to base64", error);
            }
        }
    };

    return (
        <>
            {answers.map((answer, index: number) => (
                <div className="answer-cell" key={`${indexQuestion}-${index}`}>
                    {index === 0 ? (
                        <p className="greenIcon">
                            <CheckOutlinedIcon />
                        </p>
                    ) : (
                        <p className="redIcon">
                            <CloseOutlinedIcon />
                        </p>
                    )}
                    <input
                        type="file"
                        id={`answer-${index}`}
                        accept="audio/mpeg, audio/wav"
                        onChange={(e) => handleFileChange(e, indexQuestion, index)}
                        style={{ width: "250px" }}
                    />
                    {previews[index] && (
                        <audio controls style={{ width: "400px" }}>
                            <source src={previews[index]} type="audio/mpeg" />
                            Your browser does not support the audio element.
                        </audio>
                    )}
                    <div
                        onClick={(e) => {
                            e.preventDefault();
                            handleDeleteAnswer(e, indexQuestion, index);
                        }}
                    >
                        {index > 1 ? <DeleteOutlineOutlinedIcon className="redIcon" /> : null}
                    </div>
                </div>
            ))}
        </>
    );
}
