import DeleteOutlineOutlinedIcon from "@mui/icons-material/DeleteOutlineOutlined";
import CheckOutlinedIcon from "@mui/icons-material/CheckOutlined";
import CloseOutlinedIcon from "@mui/icons-material/CloseOutlined";
import { Answer, AnswerCreation } from "../../models/Answer";
import GenerateAnswer from "./generateAnswer/generateAnswer";

interface ITextQuizProps {
    question: string;
    answers: AnswerCreation[];
    indexQuestion: number;
    updateAnswer: (text: string, indexQuestion: number, index: number) => void;
    handleDeleteAnswer: (e: React.MouseEvent, indexQuestion: number, index: number) => void;
}

export default function TextQuiz({
    question,
    answers,
    indexQuestion,
    updateAnswer,
    handleDeleteAnswer,
}: ITextQuizProps) {
    const handleGeneratedAnswer = (index: number, text: string) => {
        updateAnswer(text, indexQuestion, index);
    };

    return (
        <>
            {answers.map((answer, index: number) => (
                <div className="answer-cell" key={`${indexQuestion}-${index}`}>
                    {index === 0 ? (
                        <p className="greenIcon">
                            <CheckOutlinedIcon />
                        </p>
                    ) : (
                        <p className="redIcon">
                            <CloseOutlinedIcon />
                        </p>
                    )}
                    <input
                        type="text"
                        id="answer"
                        defaultValue={answer.text}
                        value={answer.text}
                        placeholder={index === 0 ? "Write true answer..." : "Write false answer..."}
                        onChange={(e) => {
                            updateAnswer(e.target.value, indexQuestion, index);
                        }}
                    />
                    <GenerateAnswer
                        question={question}
                        index={index}
                        updateAnswer={(text) => handleGeneratedAnswer(index, text)}
                    />
                    <div
                        onClick={(e) => {
                            e.preventDefault();
                            handleDeleteAnswer(e, indexQuestion, index);
                        }}
                    >
                        {index > 1 ? <DeleteOutlineOutlinedIcon className="redIcon" /> : null}
                    </div>
                </div>
            ))}
        </>
    );
}
