import { useEffect, useState } from "react";

import "./editQuiz.css";
import { useQuizService } from "../../services/QuizService";
import { QuestionCreation } from "../../models/Question";
import { QuizCreation } from "../../models/Quiz";
import TextQuiz from "./textQuiz";
import ImageQuiz from "./imageQuiz";
import SoundQuiz from "./soundQuiz";
const QUESTIONS: QuestionCreation[] = [];

export function EditQuiz() {
    const { getQuiz } = useQuizService();
    const [quiz, setQuiz] = useState<QuizCreation>({
        name: "",
        description: "Default description",
        difficulty: "easy",
        questions: QUESTIONS,
    });
    const [mode, setMode] = useState<string>("text");

    const fetchingQuiz = async (idQuiz: string) => {
        const quiz = await getQuiz(idQuiz);
        quiz.title = quiz.name;
        const titleElement = document.getElementById("title") as HTMLInputElement;
        titleElement.value = quiz.name;
        const difficultyElement = document.getElementById("difficulty") as HTMLSelectElement;
        if (quiz.questions[0].answers[0].text.includes("data:image")) {
            setMode("image");
            const quizType = document.getElementById("quizType") as HTMLSelectElement;
            quizType.value = "image";
        } else if (quiz.questions[0].answers[0].text.includes("data:audio")) {
            setMode("sound");
            const quizType = document.getElementById("quizType") as HTMLSelectElement;
            quizType.value = "sound";
        }
        difficultyElement.value = quiz.difficulty?.name;
        setQuiz(quiz);
    };

    useEffect(() => {
        const idQuiz = localStorage.getItem("editQuiz") || null;
        fetchingQuiz(idQuiz);
    }, []);

    return (
        <>
            <div className="create-header">
                <h1>
                    Quiz : {quiz.name} ({localStorage.getItem("editQuiz")})
                </h1>
            </div>
            <div className="create-container">
                <div className="create-quiz-info">
                    <div className="create-quiz-info-wrapper">
                        <div className="create-label-wrapper">
                            <label>QUIZ TITLE </label>
                        </div>
                        <input type="text" id="title" placeholder="Write the quiz title..." disabled />
                    </div>
                    <div className="create-quiz-info-wrapper">
                        <div className="create-label-wrapper">
                            <label>QUIZ DIFFICULTY </label>
                        </div>
                        <select id="difficulty" disabled>
                            <option value="easy">Easy</option>
                            <option value="medium">Medium</option>
                            <option value="hard">Hard</option>
                        </select>
                    </div>
                    <div className="create-quiz-info-wrapper">
                        <div className="create-label-wrapper">
                            <label>Quiz type</label>
                        </div>
                        <select id="quizType" disabled>
                            <option value="text">Text</option>
                            <option value="image">Image</option>
                            <option value="sound">Sound</option>
                        </select>
                    </div>
                </div>
                <hr />
                <div className="create-question-info">
                    <div className="create-question-table">
                        {quiz.questions.map((question, indexQuestion) => (
                            <div className="create-question-row" key={indexQuestion}>
                                <div className="cell question-cell">
                                    <div className="create-label-wrapper">
                                        <label>QUESTION {indexQuestion + 1} </label>
                                    </div>
                                    <input
                                        type="text"
                                        id="question"
                                        placeholder="Write a question..."
                                        defaultValue={question.text}
                                        value={question.text}
                                        disabled
                                    />
                                </div>
                                <div className="cell answers-cell" id="answers">
                                    <div className="create-label-wrapper">
                                        <label>ANSWERS </label>
                                    </div>
                                    <div className="answer-wrapper">
                                        <div className="answers-list">
                                            {mode === "text" && (
                                                <TextQuiz answers={question.answers} indexQuestion={indexQuestion} />
                                            )}
                                            {mode === "image" && (
                                                <ImageQuiz answers={question.answers} indexQuestion={indexQuestion} />
                                            )}
                                            {mode === "sound" && (
                                                <SoundQuiz answers={question.answers} indexQuestion={indexQuestion} />
                                            )}
                                        </div>
                                    </div>
                                </div>
                                <hr />
                            </div>
                        ))}
                    </div>
                </div>
            </div>
        </>
    );
}
