// right side for home, show the history of unfinished quizzes

import { useEffect, useState } from "react";
import { List } from "../../../components/list/list";
import { useQuizService } from "../../../services/QuizService";
import "./myQuizzes.css";
import ListModel from "../../../models/ListModel";
import { Quiz } from "../../../models/Quiz";
import HttpError from "../../../services/HttpError";
import { useNavigate } from "react-router-dom";
import { Run } from "../../../models/Run";
import { useUserService } from "../../../services/UserService";

interface paqProps {
    loading: () => void;
}

export function MyQuizzes({ loading }: paqProps) {
    const [selected, setSelected] = useState<string>("");
    const [isLoading, setIsLoading] = useState<boolean>(false);
    const [liste, setListe] = useState<ListModel[]>([]);
    const [runList, setRunList] = useState<Run[] | null>();
    const [run, setRun] = useState<Run | null>();
    const { getInformationsUser } = useUserService();
    const { getUserRuns } = useQuizService();
    const navigate = useNavigate();
    const [isConnected, setIsConnected] = useState<boolean>(false);
    const fetchuserRun = async () => {
        const response = await getUserRuns();
        if (response instanceof HttpError) {
            console.error("Error while fetching user runs:", response);
            setIsConnected(false);
            return;
        }
        setIsConnected(true);
        setRunList(response.runs);
        const tempList: ListModel[] = response.runs.map((run) => {
            return {
                id: run.id,
                title: run.quiz?.category?.name?.toUpperCase() || run.quizId,
                content:
                    run.questionIndex +
                    "/" +
                    run.quiz.questionCount +
                    " QUESTIONS | " +
                    run.quiz.difficulty.name.toUpperCase(),
            };
        });
        setListe(tempList);
    };

    const updateList = () => {
        fetchuserRun();
    };

    useEffect(() => {
        setIsLoading(true);
        updateList();
        setIsLoading(false);
    }, []);

    useEffect(() => {
        if (selected && runList) {
            const selectedRun = runList.find((quiz) => quiz.id === selected.toString());
            setRun(selectedRun || null);
        }
    }, [selected]);

    const handlePlay = () => {
        if (!run) return;
        if (!selected) return;
        console.log("selected", selected);
        navigate("/quiz/" + selected, { state: { quizId: run.quizId } });
    };

    const login = async () => {
        navigate("/profile");
    }

    return (
        <div className="container-mq">
            <p className="title">My recent quiz</p>
            <input type="search" className="inputRecherche" />
            {isConnected ?
                <div className="scrollable-list">
                    {isLoading ? (
                        <div className="center-loading-spinner-container" />
                    ) : (
                        <List list={liste} selected={selected} setSelected={setSelected} isLoading={false} />
                    )}
                </div>
                :
                <div className="scrollable-list">
                    <div className="login-container">
                        <p>You need to login</p>
                        <button className="blueButton" onClick={login}>Log in</button>
                    </div>
                </div>
            }

            <input type="submit" value="PLAY" className="blueButton" onClick={handlePlay} />
        </div>
    );
}
