// To join a quiz by id
import { useState } from 'react';
import './joinAQuiz.css';
import { useQuizService } from '../../../services/QuizService';
import { useNavigate } from 'react-router-dom';
import {Quiz} from "../../../models/Quiz.ts";
import HttpError from "../../../services/HttpError.ts";
import {QuizInformations} from "../../../models/QuizInformations.ts";
import {RunInformations} from "../../../models/RunInformation.ts";

interface paqProps {
    loading: () => void;
}

export function JoinAQuiz({ loading }: paqProps) {
    const [errMessage, setErrMessage] = useState<string>('No quiz found');
    const { getRunsInfo, getQuizInformations } = useQuizService();
    const navigate = useNavigate();
    const [runInformations, setRunInformations] = useState<RunInformations>();
    const [quizInformations, setQuizInformations] = useState<QuizInformations>();

    const changeIDQuiz = async (event: any) => {
        const runId = event.target.value;
        if (runId.length === 6) {
            const runFetched = await getRunsInfo(runId);
            if (runFetched instanceof HttpError) {
                setErrMessage("The quiz does not exist");
                console.log("The quiz does not exist");
                setQuizInformations(null);
                setQuizInformations(null);
                return;
            }
            const quizInformations = await getQuizInformations(runFetched.quizId);
            if (quizInformations instanceof HttpError) {
                setErrMessage("The quiz does not exist");
                return;
            }
            setRunInformations(runFetched);
            setQuizInformations(quizInformations);
        } else {
            setErrMessage('No quiz found');
            setQuizInformations(null);
            setQuizInformations(null);
        }
    }

    const handleGo = () => {
        if (!runInformations) {
            return
        } else {
            navigate('/quiz/' + runInformations.id,  { state: { quizId: runInformations.quizId } });
        }
    }

    return (
        <div className="container-jaq">
            <p className="title">Join a quiz</p>
            <form>
                <div className="form-group">
                    <input type="text" className="inputRecherche" placeholder="code..." onChange={changeIDQuiz} />
                </div>
            </form>
            <div className="quiz-info">
                <div className="quiz-title">
                    <p className="quiz-info-title">Quiz information</p>
                    <hr />
                </div>
                {runInformations && quizInformations ? (<>
                        <div className="quiz-info-content">
                            <p className="quiz-info-content-title">Category :</p>
                            <p className="quiz-info-content-value">{quizInformations.category.name}</p>
                        </div>
                        <div className="quiz-info-content">
                            <p className="quiz-info-content-title">Nb. questions :</p>
                            <p className="quiz-info-content-value">{quizInformations.questionCount}</p>
                        </div>
                        <div className="quiz-info-content">
                            <p className="quiz-info-content-title">Score :</p>
                            <p className="quiz-info-content-value">{runInformations.score}</p>
                        </div>
                    </>)
                    : (<div className="quiz-info-content">
                        <p className="quiz-info-content-value">{errMessage}</p>
                    </div>)
                }
            </div>

            <button className="blueButton" onClick={handleGo}>Go !</button>
        </div>

    );
}
