import { FormEventHandler, useEffect, useState } from "react";
import "./createALobby.css";
import { useQuizService } from "../../../services/QuizService";
import { useNavigate } from "react-router-dom";
import { Category } from "../../../models/Quiz";
import HttpError from "../../../services/HttpError";

interface paqProps {
    loading: () => void;
}

export function CreateALobby({ loading }: paqProps) {
    const { generateQuiz, getCategories } = useQuizService();
    const navigate = useNavigate();
    const [categories, setCategories] = useState<Category[]>([]);

    const fetchingCategories = async () => {
        const categories = await getCategories();
        let categoriesTemp: Category[] = [];
        categories.map((category) => {
            categoriesTemp.push({ name: category.name, id: category.id });
        });
        setCategories(categoriesTemp);
    };

    useEffect(() => {
        fetchingCategories();
    }, []);

    const handleCreate: FormEventHandler<HTMLFormElement> = async (event) => {
        event.preventDefault();
        loading();
        const playersCount = event.currentTarget.nbPlayers.value;
        const quiz = await generateQuiz(
            parseInt(event.currentTarget.nbQuestions.value),
            parseInt(event.currentTarget.category.value),
            event.currentTarget.difficulty.value
        );
        if (quiz instanceof HttpError) {
            console.error("Error while fetching generate quiz:", quiz);
            return;
        }
        console.log("handleCreate");
        navigate("/lobby/"+ quiz.quizId, { state: { isHost: true } });
    };

    return (
        <div className="container-caq">
            <p className="title">Create a lobby</p>
            <form className="form" onSubmit={handleCreate}>
                <div className="form-group">
                    <label htmlFor="difficulty">difficulty</label>
                    <select className="form-control" name="difficulty">
                        <option value="easy">Easy</option>
                        <option value="medium">Medium</option>
                        <option value="hard">Hard</option>
                    </select>
                </div>

                <div className="form-group">
                    <label htmlFor="category">Category</label>
                    <select className="form-control" id="category">
                        {categories.map((category) => {
                            return (
                                <option key={category.id} value={category.id}>
                                    {category.name}
                                </option>
                            );
                        })}
                    </select>
                </div>

                <div className="form-group">
                    <label htmlFor="nbQuestion">Nb. questions</label>
                    <input
                        type="number"
                        className="form-control"
                        placeholder="nombre de questions"
                        defaultValue="10"
                        name="nbQuestions"
                    />
                </div>
                <div className="form-group">
                    <label htmlFor="nbPlayer">Nb. players</label>
                    <input
                        type="number"
                        className="form-control"
                        placeholder="nombre de joueurs"
                        defaultValue="10"
                        name="nbPlayers"
                    />
                </div>
                <div className="button-group">
                    <button className="blueButton" type="submit">
                        Create Lobby
                    </button>
                </div>
            </form>
        </div>
    );
}
