import { useEffect, useState } from "react";

import "./multiplayer.css";
import { PlayAQuiz } from "./PlayAQuiz/playAQuiz";
import { OngoingQuizzes } from "./OngoingQuizzes/ongoingQuizzes";
import { useQuizService } from "../../services/QuizService";
import { useNavigate } from "react-router-dom";
import { useUserService } from "../../services/UserService";
import HttpError from "../../services/HttpError";
import Swal from "sweetalert2";
import { SleddingRounded } from "@mui/icons-material";
import { StyledEngineProvider } from "@mui/material";

enum MultiplayerState {
    LOADING = "LOADING",
    SHOWPAGE = "SHOWPAGE",
}

export function Multiplayer() {
    const [paq, setPaq] = useState(false); // Play A Quiz Selected
    const [mq, setMq] = useState(false); // My Quizzes Selected
    const [multiplayerState, setMultiplayerState] = useState<MultiplayerState>(MultiplayerState.SHOWPAGE);
    const { getInformationsUser } = useUserService();
    const { getRandomQuiz } = useQuizService();
    const navigate = useNavigate();

    useEffect(() => {
        isConnected();
    }, []);

    const showPaq = () => {
        setPaq(true);
        setMq(false);
    };

    const showMq = () => {
        setPaq(false);
        setMq(true);
    };

    const changeLoading = () => {
        multiplayerState === MultiplayerState.LOADING
            ? setMultiplayerState(MultiplayerState.SHOWPAGE)
            : setMultiplayerState(MultiplayerState.LOADING);
    };

    const goCommunity = async () => {
        setPaq(false);
        setMq(false);

        // setMultiplayerState(MultiplayerState.LOADING);
        // const codeQuiz = await getRandomQuiz();
        // setMultiplayerState(MultiplayerState.SHOWPAGE);
        // if (codeQuiz instanceof Error) {
        //     console.error("Error while fetching random quiz:", codeQuiz);
        //     return;
        // }
        navigate("/community?isMulti=true");
    };

    const isConnected = async () => {
        const user = await getInformationsUser();
        if (user instanceof HttpError) {
            await handleDisconnected();
        }
    };

    const handleDisconnected = () => {
        Swal.fire({
            title: "You are not connected?",
            text: "You have to be connected to play online!",
            icon: "warning",
            showCancelButton: false,
            confirmButtonColor: "#3085d6",
            cancelButtonColor: "#d33",
            confirmButtonText: "Login !",
        }).then((result) => {
            if (result.isConfirmed) {
                navigate("/profile");
            }
        });
    };

    return (
        <>
            {multiplayerState === MultiplayerState.LOADING ? (
                <div className="center-loading-spinner-container">
                    <div className="center-loading-spinner"></div>
                </div>
            ) : (
                <div className="container-right">
                    <div className="left-side">
                        <img src="LogoApp.png" className="logo" />
                        {multiplayerState === MultiplayerState.SHOWPAGE && (
                            <div className="navigation-button">
                                <button onClick={goCommunity}>Community</button>
                                <button onClick={showPaq}>Play an online quiz</button>
                                {/* <button onClick={showMq}>Ongoing quizzes</button> */}
                            </div>
                        )}
                    </div>
                    <div className="right-side">
                        {paq && <PlayAQuiz loading={changeLoading} />}
                        {mq && <OngoingQuizzes loading={changeLoading} />}
                    </div>
                </div>
            )}
        </>
    );
}
