import "./quiz.css";
import { useEffect, useState } from "react";
import { useMultiplayerService } from "../../../services/MultiplayerService.ts";
import { QuizTopMulti } from "./quizTop/QuizTopMulti.tsx";
import { QuizBotMulti } from "./quizBot/QuizBotMulti.tsx";
import { EndQuizModalMulti } from "../endQuizModal/endQuizModalMulti.tsx";
import { MultiplayerQuizInformations } from "../../../models/QuizInformations.ts";
import { Question } from "../../../models/Question.ts";
import { useLocation } from "react-router-dom";
import { useQuizService } from "../../../services/QuizService.ts";
import { useEventSourceContext } from "../../../components/EventSourceContextType.tsx";
import { PlayingQuizState } from "../../../models/PlayingQuizState.ts";
import { StopQuizModal } from "../../../components/quiz/stopQuizModal/stopQuizModal.tsx";
import { UserEndQuiz } from "../../../models/UserEndQuiz.ts";
import { shuffleAnswers } from "../../../utils/QuizHelper.ts";


enum QuizState {
    LOADING = "Loading",
    ERROR = "Error",
    OK = "Ok",
}
export function PlayingQuizMulti() {
    const { nextQuestion } = useMultiplayerService();
    const [quizState, setQuizState] = useState<QuizState>(QuizState.LOADING);
    const [playingQuizState, setPlayingQuizState] = useState<PlayingQuizState>(PlayingQuizState.LOADING)
    const [stopQuizModalIsOpen, setStopQuizModalIsOpen] = useState(false);
    const [errorMessage, setErrorMessage] = useState("");
    const [endQuizModalIsOpen, setEndQuizModalIsOpen] = useState(false);
    const [actualQuestion, setActualQuestion] = useState<Question | undefined>(undefined);
    const [quizInformations, setQuizInformations] = useState<MultiplayerQuizInformations>();
    const [score, setScore] = useState(0);
    const { eventSource } = useEventSourceContext();
    const location = useLocation();
    const [users, setUsers] = useState<UserEndQuiz[]>([]);

    const isHost = location.state?.isHost;
    const questionCount = location.state?.questionCount;


    const initES = async () => {
        eventSource.addEventListener("nextQuestion", async (event) => {
            console.log("nextQuestion event data:", event.data);
            if (!event.data) return;
            const question: Question = JSON.parse(event.data);
            console.log("setActualQuestion");
            setActualQuestion(shuffleAnswers(question));
            setQuizState(QuizState.OK);
            setPlayingQuizState(PlayingQuizState.ANSWERING);
        });

        eventSource.addEventListener("gameEnded", (event) => {
            console.log("gameEnded event data:");
            if (!event.data) return;
            const users: UserEndQuiz[] = JSON.parse(event.data);
            console.log("users:", users);
            setUsers(users);
            setEndQuizModalIsOpen(true);
        });
    }

    useEffect(() => {
        initES();
        console.log("fetching first question");
        nextQuestion();
    }, []);


    return (
        <div className="quiz-container">
            {quizState === QuizState.LOADING ? (
                <div className="center-loading-spinner-container">
                    <div className="center-loading-spinner"></div>
                </div>
            ) : (
                <>
                    <QuizTopMulti quizInformations={null} actualQuestion={actualQuestion} score={score} questionCount={questionCount} setStopQuizModalIsOpen={setStopQuizModalIsOpen} />
                    <QuizBotMulti actualQuestion={actualQuestion} isHost={isHost} setPlayingQuizState={setPlayingQuizState} playingQuizState={playingQuizState} OpenModalEndQuiz={setEndQuizModalIsOpen} setScore={setScore} />
                    <StopQuizModal isOpen={stopQuizModalIsOpen} onClose={() => setStopQuizModalIsOpen(false)} />
                    {!endQuizModalIsOpen ? null : <EndQuizModalMulti
                        isOpen={endQuizModalIsOpen}
                        onClose={null}
                        users={users}
                        questionCount={questionCount}
                        score={score}
                    />
                    }
                </>
            )}
            {/*{playingQuizState === QuizState.ERROR && <h2>Error: {errorMessage}</h2>}*/}

        </div>
    );
}
