import {useState} from "react";
import "../connect.css";
import HttpError from "../../../../services/HttpError.ts";
import {useUserService} from "../../../../services/UserService.ts";

interface loginProps {
    loginFunction: () => void;
}
export default function Login({loginFunction}: loginProps) {
    const [email, setEmail] = useState<string | null>("");
    const [password, setPassword] = useState<string | null>("");
    const [errorMessage, setErrorMessage] = useState<string | null>(null);
    const {loginUser} = useUserService();

    //Submit form to the backend
    const submit = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();
        loginUserForm();
        setPassword("");
        setEmail("");

    }

    const loginUserForm = async () => {
        if (email === "" || password === "") {
            setErrorMessage("Please fill in all fields");
            return;
        }
        const login = await loginUser(email, password);
        if(login instanceof HttpError){
            setErrorMessage(login.message);
            return;
        }
        loginFunction();

        setErrorMessage(null);
        return;
    }

    return (
        <form className="login-form" onSubmit={submit}>
            <div className="login-form-group">
                <input
                    placeholder="EMAIL"
                    value={email}
                    onChange={(e) => {
                        setEmail(e.target.value)
                    }}
                    // (blur)="checkValidity('email')"
                    className={true ? "inputText" : "inputText wrong"}
                />
                <input
                    placeholder="PASSWORD"
                    value={password}
                    onChange={(e) => {
                        setPassword(e.target.value)
                    }}
                    // (blur)="checkValidity('password')"
                    className={true ? "inputText" : "inputText wrong"}
                    type="password"
                />
                    {errorMessage !== null && <p className="login-error-message">{errorMessage}</p>}
                <button type="submit"
                        className="blueButton" style={{marginTop: "auto"}}
                >
                    LOGIN
                </button>
            </div>
        </form>
    )
}
