import {useState} from "react";
import "../connect.css";
import HttpError from "../../../../services/HttpError.ts";
import {useUserService} from "../../../../services/UserService.ts";
export default function Signup() {
    const [email, setEmail] = useState<string | null>(null);
    const [password, setPassword] = useState<string | null>(null);
    const [username, setUsername] = useState<string | null>(null);
    const [confirmPassword, setConfirmPassword] = useState<string | null>(null);
    const [errorMessage, setErrorMessage] = useState<string | null>(null);
    const [successMessage, setSuccessMessage] = useState<string | null>(null);
    const {registerUser} = useUserService();

    const submit = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();
        signupUserForm();
    }
    const clearFields = () => {
        setUsername("");
        setEmail("");
        setPassword("");
        setConfirmPassword("");
    }

    const signupUserForm = async () => {
        if (email === "" || password === "" || confirmPassword === "") {
            setErrorMessage("Please fill in all fields");
            return;
        }
        if(password.length < 8){
            setErrorMessage("Password must be at least 8 characters long");
            return;
        }
        if (password !== confirmPassword) {
            setErrorMessage("Passwords do not match");
            return;
        }
        const register = await registerUser(username, password, email);
        if(HttpError.isHttpError(register)){
            setErrorMessage(register.message);
            return;
        }
        if(register){
            setSuccessMessage("Account created");
            clearFields();
            setTimeout(() => {
                setSuccessMessage(null);
            }, 3000);
        }
        setErrorMessage(null);
        return;
    }

  return (
      <form className="login-form" onSubmit={submit}>
      <div className="login-form-group">
          <input
              placeholder="EMAIL"
              value={email}
              onChange={(e) => {
                  setEmail(e.target.value)
              }}
              // (blur)="checkValidity('email')"
              className={true ? "inputText" : "inputText wrong"}
          />
          <input
              placeholder="USERNAME"
              value={username}
              onChange={(e) => {
                  setUsername(e.target.value)
              }}
              // (blur)="checkValidity('confirm_password')"
              className={true ? "inputText" : "inputText wrong"}
          />
          <input
              placeholder="PASSWORD"
              value={password}
              onChange={(e) => {
                  setPassword(e.target.value)
              }}
              // (blur)="checkValidity('password')"
              className={true ? "inputText" : "inputText wrong"}
              type="password"
          />
          <input
              placeholder="CONFIRM PASSWORD"
              value={confirmPassword}
              onChange={(e) => {
                  setConfirmPassword(e.target.value)
              }}
              // (blur)="checkValidity('confirm_password')"
              className={true ? "inputText" : "inputText wrong"}
              type="password"
          />
          {errorMessage !== null && <p className="login-error-message">{errorMessage}</p>}
          {successMessage !== null && <p className="login-success-message">{successMessage}</p>}
          <button type="submit"
                  className="blueButton" style={{marginTop: "auto"}}
          >
              SIGN UP
          </button>
      </div>
    </form>
  );
}
