import { useEffect, useState } from "react";
import { YourQuizzes } from "./yourQuizzes/yourQuizzes";
import { Connect } from "./connect/connect.tsx";
import LogoutIcon from "@mui/icons-material/Logout";

import "./profile.css";
import { useUserService } from "../../services/UserService.ts";
import HttpError from "../../services/HttpError.ts";
import { User } from "../../models/User.ts";

//show your profile and statistics on the left side. include components as right side

enum UserConnectionState {
    LOADING = "Loading",
    NOT_CONNECTED = "NotConnected",
    CONNECTED = "Connected",
}
export function Profile() {
    const [isLogged, setIsLogged] = useState(false);
    const [user, setUser] = useState<User | null>(null);
    const { getInformationsUser, logoutUser } = useUserService();
    // const [userConnectionState, setUserConnectionState] = useState(UserConnectionState.OK);
    const [userConnectionState, setUserConnectionState] = useState(UserConnectionState.LOADING);

    const getUser = async () => {
        setUserConnectionState(UserConnectionState.LOADING);
        const user = await getInformationsUser();
        if (user instanceof HttpError) {
            setUser(null);
            setUserConnectionState(UserConnectionState.NOT_CONNECTED);
            return;
        }
        setUserConnectionState(UserConnectionState.CONNECTED);
        setUser(user);
    };
    // Pour être lancé par défaut
    useEffect(() => {
        getUser();
    }, []);

    // Pour s'adapter quand l'état de connexion change
    useEffect(() => {
        getUser();
    }, [isLogged]);
    const login = () => {
        setIsLogged(true);
    };

    const logout = async () => {
        const result = await logoutUser();
        if (HttpError.isHttpError(result)) {
            console.error("Error while logging out:", result);
            return;
        }
        if (result) {
            setIsLogged(false);
            setUserConnectionState(UserConnectionState.NOT_CONNECTED);
            setUser(null);
        }
    };

    return (
        <>
            <div className="profile-top">
                {userConnectionState === UserConnectionState.CONNECTED && (
                    <>
                        <h1>Your profile</h1>
                        <button className="logout-button" onClick={logout}>
                            <LogoutIcon sx={{ fontSize: "2.5vw", color: "red" }} />
                        </button>
                    </>
                )}
            </div>
            <div className="profile-content">
                {userConnectionState === UserConnectionState.LOADING && (
                    <div>
                        <h3>Loading...</h3>
                        <div className="loading-spinner"></div>
                    </div>
                )}
                {userConnectionState === UserConnectionState.CONNECTED && (
                    <>
                        <div className="profile-rightSide">
                            <h3>Your stats</h3>
                            <div className="profile-container">
                                <div className="grid-profile">
                                    <div className="profile_info">
                                        <img
                                            src="https://cdn.pixabay.com/photo/2015/10/05/22/37/blank-profile-picture-973460_1280.png"
                                            alt="profile picture"
                                        />
                                        <h3>{user ? user.username : "Not logged in"}</h3>
                                    </div>
                                    <hr />
                                    <div className="profile_stats">
                                        <div className="user-stats-container">
                                            <ul className="user-stats-list">
                                                <li>
                                                    <span className="stat-title">Quizzes created:</span>
                                                    <span className="stat-value">
                                                        {user ? user.stats.quizzesCreated : "?"}
                                                    </span>
                                                </li>
                                                <li>
                                                    <span className="stat-title">Quizzes played:</span>
                                                    <span className="stat-value">
                                                        {user ? user.stats.quizzesPlayed : "?"}
                                                    </span>
                                                </li>
                                                <li>
                                                    <span className="stat-title">Correct answers:</span>
                                                    <span className="stat-value">
                                                        {user ? user.stats.correctAnswers : "?"}
                                                    </span>
                                                </li>
                                                <li>
                                                    <span className="stat-title">Total responses:</span>
                                                    <span className="stat-value">
                                                        {user ? user.stats.totalAnswers : "?"}
                                                    </span>
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div className="profile-leftSide">
                            <h3>Your quizzes</h3>
                            <YourQuizzes userid={user.id} />
                        </div>
                    </>
                )}
                {userConnectionState === UserConnectionState.NOT_CONNECTED && (
                    <div className="profile-leftSide profile-signin">
                        <h1 className="signin-text">SIGN IN TO SKITSKOLA</h1>
                        <Connect loginFunction={login} />
                    </div>
                )}
            </div>
        </>
    );
}
