import { useNavigate } from "react-router-dom";
import { useQuizService } from "../../../services/QuizService";
import { useState, useEffect } from "react";
import { Quiz } from "../../../models/Quiz";
import { List } from "../../../components/list/list";
import "./yourQuizzes.css";

export function YourQuizzes({ userid }: { userid: number }) {
    const { getQuizForUser } = useQuizService();
    const navigate = useNavigate();
    const [quizzes, setQuizzes] = useState<Quiz[]>([]);
    const [isLoading, setIsLoading] = useState<boolean>(true);
    const [selectedQuiz, setSelectedQuiz] = useState<string>("");

    const fetchQuizzes = async () => {
        setIsLoading(true);
        try {
            const quizzes = await getQuizForUser(userid);
            setQuizzes(quizzes);
        } catch (error) {
            console.error("Failed to fetch quizzes:", error);
        } finally {
            setIsLoading(false);
        }
    };

    useEffect(() => {
        fetchQuizzes();
    }, [userid]);

    useEffect(() => {
        if (selectedQuiz) {
            localStorage.setItem("editQuiz", selectedQuiz);
            navigate(`/editquiz`);
        }
    }, [selectedQuiz]);

    return (
        <>
            {/* <div className="profile-container"> */}
            <div className="scrollable-list; profile-container">
                <List
                    list={quizzes.map((quiz) => ({
                        id: quiz.id,
                        title: quiz.name,
                        content: quiz.questionCount + " QUESTIONS" + " | " + quiz.difficulty.name.toUpperCase(),
                    }))}
                    setSelected={setSelectedQuiz}
                    selected={selectedQuiz}
                    isLoading={isLoading}
                />
            </div>
            <div className="new-quiz">
                <button
                    onClick={() => {
                        navigate("/createquiz");
                    }}
                    className="blueButton"
                    id="create-quiz"
                >
                    Create a new quiz
                </button>
            </div>
            {/* </div> */}
        </>
    );
}
