import HttpError from './HttpError';
import axios from 'axios';

export const useMultiplayerService = () => {
    const url = import.meta.env.VITE_API_URL;

    const createParty = async (quizId: string) : Promise<string | HttpError> => {
        console.log("Create party with ID :", quizId);
        console.log(url+"/party");
        const requestBody = {
            quizId: quizId,
        };

        try {
            console.log("avant");
            const response = await axios.post(`${url}/party`, requestBody, {
                withCredentials: true,
                timeout: 5000
            });
            console.log("après");
            console.log("Response data:", response.data.id);
            return response.data.id;
        } catch (error: any) {
            console.log("Error while create party:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    }

    const generateRun = async () : Promise<string | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/generateRun`, {
                withCredentials: true,
            });
            return response.data.runId;
        } catch (error: any) {
            console.log("Error while generate run:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const revealAnswer = async () : Promise<boolean | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/revealAnswer`, {
                withCredentials: true,
            });
            return true;
        } catch (error: any) {
            console.log("Error while reveal Answer:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const answerQuestion = async (questionId: number, answerId: number) : Promise<boolean | HttpError> => {
        const requestBody = {
            questionId: questionId,
            answerId: answerId,
        };

        try {
            const response = await axios.post(`${url}/party/answer`, requestBody,{
                withCredentials: true,
            });
            return true;
        } catch (error: any) {
            console.log("Error while reveal Answer:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const nextQuestion = async () : Promise<boolean | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/nextQuestion`, {
                withCredentials: true,
            });
            return true;
        } catch (error: any) {
            console.log("Error while nextQuestion:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const startParty = async () : Promise<boolean | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/start`, {
                withCredentials: true,
            });
            return true;
        } catch (error: any) {
            console.log("Error while startParty:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const joinLobby = async (lobbyId: string): Promise<any> => {
        return {
            isHost: true,
        };
    };

    const recivedPlayers = async (): Promise<any> => {};

    const recivedStart = async (): Promise<any> => {};

    const recivedQuestion = async (): Promise<any> => {};

    const sendAnswer = async (codeQuiz: string, questionID: number, answerID: number): Promise<any> => {};

    const recivedResults = async (): Promise<any> => {};

    const recivedEnd = async (): Promise<any> => {};

    const lobbyInfos = async (lobbyId: string): Promise<any> => {
        return { id: lobbyId, questionCount: 12, category: { id: 18, name: 'Anumals' } };
    };

    const getCategories = async () => {
        try {
            const response = await axios.get(`${url}/quiz/categories`, {
                headers: {
                    'Content-Type': 'application/json',
                },
            });
            return response.data;
        } catch (error: any) {
            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || 'HTTP error');
            } else {
                return new HttpError(500, 'Unexpected error: ' + error.message);
            }
        }
    };

    const getScore = async () : Promise<number | HttpError> => {
        console.log("getScore");
        try {
            const response = await axios.get(`${url}/party/score`, {
                withCredentials: true,
            });
            console.log("getScore done");
            return response.data.score;
        } catch (error: any) {
            console.log("Error while startParty:", error);

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    return {
        createParty,
        getCategories,
        startParty,
        recivedQuestion,
        recivedResults,
        recivedEnd,
        recivedStart,
        sendAnswer,
        joinLobby,
        recivedPlayers,
        lobbyInfos,
        generateRun,
        revealAnswer,
        answerQuestion,
        nextQuestion,
        getScore,
    };
};
