import axios from "axios";
import HttpError from "./HttpError";

export const useOllamaService = () => {
    const url = import.meta.env.VITE_API_URL;

    const generateTrueAnswer = async (question) => {
        const requestBody = {
            question,
        };

        try {
            const response = await axios.post(`${url}/ollama/TrueAnswer`, requestBody, {
                headers: {
                    'Content-Type': 'application/json',
                },
            });
            return response.data;
        } catch (error: any) {
            console.log('Error while generating quiz:', error);

            if (error.response) {
                // Gestion des erreurs HTTP
                return new HttpError(error.response.status, error.response.data?.message || 'HTTP error');
            } else {
                // Gestion des erreurs réseau ou autres
                return new HttpError(500, 'Unexpected error: ' + error.message);
            }
        }
    };

    const generateFalseAnswer = async (question, mode) => {
        const requestBody = {
            question,
            mode,
        };

        try {
            const response = await axios.post(`${url}/ollama/FalseAnswer`, requestBody, {
                headers: {
                    'Content-Type': 'application/json',
                },
            });
            return response.data;
        } catch (error: any) {
            console.log('Error while generating quiz:', error);

            if (error.response) {
                // Gestion des erreurs HTTP
                return new HttpError(error.response.status, error.response.data?.message || 'HTTP error');
            } else {
                // Gestion des erreurs réseau ou autres
                return new HttpError(500, 'Unexpected error: ' + error.message);
            }
        }
    }


    return {
        generateTrueAnswer: generateTrueAnswer,
        generateFalseAnswer: generateFalseAnswer,
    };
} 